Class: Google::Cloud::Datastream::V1::MongodbProfile

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datastream/v1/datastream_resources.rb

Overview

MongoDB profile.

Instance Attribute Summary collapse

Instance Attribute Details

#host_addresses::Array<::Google::Cloud::Datastream::V1::HostAddress>

Returns Required. List of host addresses for a MongoDB cluster. For SRV connection format, this list must contain exactly one DNS host without a port. For Standard connection format, this list must contain all the required hosts in the cluster with their respective ports.

Returns:

  • (::Array<::Google::Cloud::Datastream::V1::HostAddress>)

    Required. List of host addresses for a MongoDB cluster. For SRV connection format, this list must contain exactly one DNS host without a port. For Standard connection format, this list must contain all the required hosts in the cluster with their respective ports.



296
297
298
299
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 296

class MongodbProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#password::String

Returns Optional. Password for the MongoDB connection. Mutually exclusive with the secret_manager_stored_password field.

Returns:

  • (::String)

    Optional. Password for the MongoDB connection. Mutually exclusive with the secret_manager_stored_password field.



296
297
298
299
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 296

class MongodbProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#replica_set::String

Returns Optional. Name of the replica set. Only needed for self hosted replica set type MongoDB cluster. For SRV connection format, this field must be empty. For Standard connection format, this field must be specified.

Returns:

  • (::String)

    Optional. Name of the replica set. Only needed for self hosted replica set type MongoDB cluster. For SRV connection format, this field must be empty. For Standard connection format, this field must be specified.



296
297
298
299
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 296

class MongodbProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#secret_manager_stored_password::String

Returns Optional. A reference to a Secret Manager resource name storing the SQLServer connection password. Mutually exclusive with the password field.

Returns:

  • (::String)

    Optional. A reference to a Secret Manager resource name storing the SQLServer connection password. Mutually exclusive with the password field.



296
297
298
299
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 296

class MongodbProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#srv_connection_format::Google::Cloud::Datastream::V1::SrvConnectionFormat

Returns Srv connection format.

Note: The following fields are mutually exclusive: srv_connection_format, standard_connection_format. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Datastream::V1::SrvConnectionFormat)

    Srv connection format.

    Note: The following fields are mutually exclusive: srv_connection_format, standard_connection_format. If a field in that set is populated, all other fields in the set will automatically be cleared.



296
297
298
299
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 296

class MongodbProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ssl_config::Google::Cloud::Datastream::V1::MongodbSslConfig

Returns Optional. SSL configuration for the MongoDB connection.

Returns:



296
297
298
299
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 296

class MongodbProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#standard_connection_format::Google::Cloud::Datastream::V1::StandardConnectionFormat

Returns Standard connection format.

Note: The following fields are mutually exclusive: standard_connection_format, srv_connection_format. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Datastream::V1::StandardConnectionFormat)

    Standard connection format.

    Note: The following fields are mutually exclusive: standard_connection_format, srv_connection_format. If a field in that set is populated, all other fields in the set will automatically be cleared.



296
297
298
299
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 296

class MongodbProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#username::String

Returns Required. Username for the MongoDB connection.

Returns:

  • (::String)

    Required. Username for the MongoDB connection.



296
297
298
299
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 296

class MongodbProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end