Class: Google::Cloud::Datastream::V1::MongodbSslConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Datastream::V1::MongodbSslConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datastream/v1/datastream_resources.rb
Overview
MongoDB SSL configuration information.
Instance Attribute Summary collapse
-
#ca_certificate ⇒ ::String
Optional.
-
#ca_certificate_set ⇒ ::Boolean
readonly
Output only.
-
#client_certificate ⇒ ::String
Optional.
-
#client_certificate_set ⇒ ::Boolean
readonly
Output only.
-
#client_key ⇒ ::String
Optional.
-
#client_key_set ⇒ ::Boolean
readonly
Output only.
-
#secret_manager_stored_client_key ⇒ ::String
Optional.
Instance Attribute Details
#ca_certificate ⇒ ::String
Returns Optional. Input only. PEM-encoded certificate of the CA that signed the source database server's certificate.
556 557 558 559 |
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 556 class MongodbSslConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ca_certificate_set ⇒ ::Boolean (readonly)
Returns Output only. Indicates whether the ca_certificate field is set.
556 557 558 559 |
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 556 class MongodbSslConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#client_certificate ⇒ ::String
Returns Optional. Input only. PEM-encoded certificate that will be used by the replica to authenticate against the source database server. If this field is used then the 'client_key' and the 'ca_certificate' fields are mandatory.
556 557 558 559 |
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 556 class MongodbSslConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#client_certificate_set ⇒ ::Boolean (readonly)
Returns Output only. Indicates whether the client_certificate field is set.
556 557 558 559 |
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 556 class MongodbSslConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#client_key ⇒ ::String
Returns Optional. Input only. PEM-encoded private key associated with the Client Certificate. If this field is used then the 'client_certificate' and the 'ca_certificate' fields are mandatory.
556 557 558 559 |
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 556 class MongodbSslConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#client_key_set ⇒ ::Boolean (readonly)
Returns Output only. Indicates whether the client_key field is set.
556 557 558 559 |
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 556 class MongodbSslConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#secret_manager_stored_client_key ⇒ ::String
Returns Optional. Input only. A reference to a Secret Manager resource name storing
the PEM-encoded private key associated with the Client Certificate. If this
field is used then the 'client_certificate' and the 'ca_certificate' fields
are mandatory. Mutually exclusive with the client_key field.
556 557 558 559 |
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 556 class MongodbSslConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |