Class: Google::Cloud::Datastream::V1::StandardConnectionFormat

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datastream/v1/datastream_resources.rb

Overview

Standard connection format.

Instance Attribute Summary collapse

Instance Attribute Details

#direct_connection::Boolean

Returns Optional. Specifies whether the client connects directly to the host[:port] in the connection URI.

Returns:

  • (::Boolean)

    Optional. Specifies whether the client connects directly to the host[:port] in the connection URI.



325
326
327
328
# File 'proto_docs/google/cloud/datastream/v1/datastream_resources.rb', line 325

class StandardConnectionFormat
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end