Class: Google::Cloud::Datastream::V1::DiscoverConnectionProfileRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Datastream::V1::DiscoverConnectionProfileRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datastream/v1/datastream.rb
Overview
Request message for 'discover' ConnectionProfile request.
Instance Attribute Summary collapse
-
#connection_profile ⇒ ::Google::Cloud::Datastream::V1::ConnectionProfile
An ad-hoc connection profile configuration.
-
#connection_profile_name ⇒ ::String
A reference to an existing connection profile.
-
#full_hierarchy ⇒ ::Boolean
Whether to retrieve the full hierarchy of data objects (TRUE) or only the current level (FALSE).
-
#hierarchy_depth ⇒ ::Integer
The number of hierarchy levels below the current level to be retrieved.
-
#mongodb_cluster ⇒ ::Google::Cloud::Datastream::V1::MongodbCluster
MongoDB cluster to enrich with child data objects and metadata.
-
#mysql_rdbms ⇒ ::Google::Cloud::Datastream::V1::MysqlRdbms
MySQL RDBMS to enrich with child data objects and metadata.
-
#oracle_rdbms ⇒ ::Google::Cloud::Datastream::V1::OracleRdbms
Oracle RDBMS to enrich with child data objects and metadata.
-
#parent ⇒ ::String
Required.
-
#postgresql_rdbms ⇒ ::Google::Cloud::Datastream::V1::PostgresqlRdbms
PostgreSQL RDBMS to enrich with child data objects and metadata.
-
#salesforce_org ⇒ ::Google::Cloud::Datastream::V1::SalesforceOrg
Salesforce organization to enrich with child data objects and metadata.
-
#sql_server_rdbms ⇒ ::Google::Cloud::Datastream::V1::SqlServerRdbms
SQLServer RDBMS to enrich with child data objects and metadata.
Instance Attribute Details
#connection_profile ⇒ ::Google::Cloud::Datastream::V1::ConnectionProfile
Returns An ad-hoc connection profile configuration.
Note: The following fields are mutually exclusive: connection_profile, connection_profile_name. If a field in that set is populated, all other fields in the set will automatically be cleared.
80 81 82 83 |
# File 'proto_docs/google/cloud/datastream/v1/datastream.rb', line 80 class DiscoverConnectionProfileRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#connection_profile_name ⇒ ::String
Returns A reference to an existing connection profile.
Note: The following fields are mutually exclusive: connection_profile_name, connection_profile. If a field in that set is populated, all other fields in the set will automatically be cleared.
80 81 82 83 |
# File 'proto_docs/google/cloud/datastream/v1/datastream.rb', line 80 class DiscoverConnectionProfileRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#full_hierarchy ⇒ ::Boolean
Returns Whether to retrieve the full hierarchy of data objects (TRUE) or only the current level (FALSE).
Note: The following fields are mutually exclusive: full_hierarchy, hierarchy_depth. If a field in that set is populated, all other fields in the set will automatically be cleared.
80 81 82 83 |
# File 'proto_docs/google/cloud/datastream/v1/datastream.rb', line 80 class DiscoverConnectionProfileRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#hierarchy_depth ⇒ ::Integer
Returns The number of hierarchy levels below the current level to be retrieved.
Note: The following fields are mutually exclusive: hierarchy_depth, full_hierarchy. If a field in that set is populated, all other fields in the set will automatically be cleared.
80 81 82 83 |
# File 'proto_docs/google/cloud/datastream/v1/datastream.rb', line 80 class DiscoverConnectionProfileRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mongodb_cluster ⇒ ::Google::Cloud::Datastream::V1::MongodbCluster
Returns MongoDB cluster to enrich with child data objects and metadata.
Note: The following fields are mutually exclusive: mongodb_cluster, oracle_rdbms, mysql_rdbms, postgresql_rdbms, sql_server_rdbms, salesforce_org. If a field in that set is populated, all other fields in the set will automatically be cleared.
80 81 82 83 |
# File 'proto_docs/google/cloud/datastream/v1/datastream.rb', line 80 class DiscoverConnectionProfileRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mysql_rdbms ⇒ ::Google::Cloud::Datastream::V1::MysqlRdbms
Returns MySQL RDBMS to enrich with child data objects and metadata.
Note: The following fields are mutually exclusive: mysql_rdbms, oracle_rdbms, postgresql_rdbms, sql_server_rdbms, salesforce_org, mongodb_cluster. If a field in that set is populated, all other fields in the set will automatically be cleared.
80 81 82 83 |
# File 'proto_docs/google/cloud/datastream/v1/datastream.rb', line 80 class DiscoverConnectionProfileRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#oracle_rdbms ⇒ ::Google::Cloud::Datastream::V1::OracleRdbms
Returns Oracle RDBMS to enrich with child data objects and metadata.
Note: The following fields are mutually exclusive: oracle_rdbms, mysql_rdbms, postgresql_rdbms, sql_server_rdbms, salesforce_org, mongodb_cluster. If a field in that set is populated, all other fields in the set will automatically be cleared.
80 81 82 83 |
# File 'proto_docs/google/cloud/datastream/v1/datastream.rb', line 80 class DiscoverConnectionProfileRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource of the connection profile type. Must be in
the format projects/*/locations/*.
80 81 82 83 |
# File 'proto_docs/google/cloud/datastream/v1/datastream.rb', line 80 class DiscoverConnectionProfileRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#postgresql_rdbms ⇒ ::Google::Cloud::Datastream::V1::PostgresqlRdbms
Returns PostgreSQL RDBMS to enrich with child data objects and metadata.
Note: The following fields are mutually exclusive: postgresql_rdbms, oracle_rdbms, mysql_rdbms, sql_server_rdbms, salesforce_org, mongodb_cluster. If a field in that set is populated, all other fields in the set will automatically be cleared.
80 81 82 83 |
# File 'proto_docs/google/cloud/datastream/v1/datastream.rb', line 80 class DiscoverConnectionProfileRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#salesforce_org ⇒ ::Google::Cloud::Datastream::V1::SalesforceOrg
Returns Salesforce organization to enrich with child data objects and metadata.
Note: The following fields are mutually exclusive: salesforce_org, oracle_rdbms, mysql_rdbms, postgresql_rdbms, sql_server_rdbms, mongodb_cluster. If a field in that set is populated, all other fields in the set will automatically be cleared.
80 81 82 83 |
# File 'proto_docs/google/cloud/datastream/v1/datastream.rb', line 80 class DiscoverConnectionProfileRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sql_server_rdbms ⇒ ::Google::Cloud::Datastream::V1::SqlServerRdbms
Returns SQLServer RDBMS to enrich with child data objects and metadata.
Note: The following fields are mutually exclusive: sql_server_rdbms, oracle_rdbms, mysql_rdbms, postgresql_rdbms, salesforce_org, mongodb_cluster. If a field in that set is populated, all other fields in the set will automatically be cleared.
80 81 82 83 |
# File 'proto_docs/google/cloud/datastream/v1/datastream.rb', line 80 class DiscoverConnectionProfileRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |